Module term_rustdoc::util
source · Expand description
common public utils
Macros
- Creates a
CompactStringusing interpolation of runtime expressions.
Structs
- A
CompactStringis a compact string type that can be used almost anywhere aStringorstrcan be used.
Traits
- A trait that provides convience methods for creating a
CompactStringfrom a collection of items. It is implemented for all types that can be converted into an iterator, and that iterator yields types that can be converted into astr. - A trait for converting a value to a
CompactString.
Functions
- Construct a
rustc_hash::FxHashMap.
Type Aliases
- Type alias for a hashmap using the
fxhash algorithm.